@@ -1,16 +1,16 @@
 package Dist::Zilla::Plugin::EnsureSQLSchemaVersionedTest;
 
-our $DATE = '2016-02-11'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2017-07-07'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
 use Moose;
-with 'Dist::Zilla::Role::InstallTool';
+with 'Dist::Zilla::Role::AfterBuild';
 
-sub setup_installer {
+sub after_build {
     my ($self) = @_;
 
     my $prereqs_hash = $self->zilla->prereqs->as_string_hash;
@@ -41,7 +41,7 @@ Dist::Zilla::Plugin::EnsureSQLSchemaVersionedTest - Make sure that xt/author/sql
 
 =head1 VERSION
 
-This document describes version 0.02 of Dist::Zilla::Plugin::EnsureSQLSchemaVersionedTest (from Perl distribution Dist-Zilla-Plugin-EnsureSQLSchemaVersionedTest), released on 2016-02-11.
+This document describes version 0.03 of Dist::Zilla::Plugin::EnsureSQLSchemaVersionedTest (from Perl distribution Dist-Zilla-Plugin-EnsureSQLSchemaVersionedTest), released on 2017-07-07.
 
 =head1 SYNOPSIS
 
@@ -100,7 +100,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
